typedef union {
	gint		val;
	char		*string;
	gboolean        gbool;  
	GString		*gstring;
	GArray		*garray;
	GList		*glist;
	KEY_VALUE	*kv;
} YYSTYPE;
#define	ADDICON	257
#define	DEFAULTDIRICON	258
#define	DEFAULTDISKICON	259
#define	DEFAULTFILEICON	260
#define	MOUNTPROGRAM	261
#define	UMOUNTPROGRAM	262
#define	EJECTPROGRAM	263
#define	MOUNTPOINT	264
#define	EXTENSION	265
#define	OPTIONDUS	266
#define	OPTIONWARNMOUNT	267
#define	OPTIONEJECT	268
#define	STRING	269
#define	QSTRING	270
#define	GBOOLEAN	271
#define	INTEGER	272
#define	EOL	273


extern YYSTYPE yylval;
